import IgsBaseLayer from "./IgsBaseLayer";

export default {
  name: "IgsWmtsLayer",
  mixins: [IgsBaseLayer],
  props: {
    wmtsLayer: {
      type: String
    },
    tileMatrixSet: {
      type: String
    },
    version: {
      type: String,
      default: "1.0.0"
    },
    wmtsStyle: {
      type: String,
      default: "default"
    },
    format: {
      type: String,
      default: "image/png"
    }
  },
  methods: {
    $_init() {
      let { url, wmtsLayer, tileMatrixSet } = this;
      if (url) {
        this._url = url;
      } else {
        if (!wmtsLayer || !tileMatrixSet) {
          return;
        }
        let baseUrl = "";
        if (this.url) {
          if (this.url.indexOf("?") > -1) {
            baseUrl = this.url.split("?")[0];
          } else {
            baseUrl = this.url;
          }
        } else {
          let tempUrl = "/igs/rest/ogc/WMTSServer";
          if (this.serverName && this.serverName !== "") {
            tempUrl = "/igs/rest/ogc/" + this.serverName + "/WMTSServer";
          }
          let domain = this.domain;
          if (!domain) {
            domain = this.protocol + "://" + this.ip + ":" + this.port;
          }
          baseUrl = domain + tempUrl;
        }
        this._zoomOffset = this.zoomOffset;
        if (baseUrl.toLowerCase().indexOf("ime-cloud") > -1) {
          //吉威的数据
          baseUrl += "?service=WMTS&REQUEST=GetTile";
        } else {
          baseUrl += "?service=WMTS&request=GetTile";
          if (this.map.getCRS().epsgCode.includes("4326")) {
            this._zoomOffset = -1;
          }
        }
        const partUrl = this.$_initAllRequestParams().join("&");
        this._url =
          encodeURI(baseUrl) +
          "&" +
          partUrl +
          "&tileMatrix={z}&tileRow={y}&tileCol={x}";
      }
    },
    $_initAllRequestParams() {
      let params = [];
      params.push("version=" + this.version);
      params.push("style=" + this.wmtsStyle || "");
      params.push("tileMatrixSet=" + this.tileMatrixSet);
      params.push("format=" + this.format);
      params.push("layer=" + this.wmtsLayer);
      if (this.token) {
        params.push("token=" + this.token);
      }
      return params;
    }
  }
};
